@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 BEGIN {
-  $CPAN::Perl::Releases::VERSION = '0.08';
+  $CPAN::Perl::Releases::VERSION = '0.10';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -161,6 +161,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.12.3-RC3.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.12.3-RC3.tar.gz"
   },
+  "5.12.4-RC1" => {
+    "tar.bz2" => "L/LB/LBROCARD/perl-5.12.4-RC1.tar.bz2",
+    "tar.gz" => "L/LB/LBROCARD/perl-5.12.4-RC1.tar.gz"
+  },
   "5.13.0" => {
     "tar.bz2" => "L/LB/LBROCARD/perl-5.13.0.tar.bz2",
     "tar.gz" => "L/LB/LBROCARD/perl-5.13.0.tar.gz"
@@ -341,7 +345,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
